@@ -106,6 +106,29 @@ action_activate (GtkAction *action)
   if (history_action->priv->direction == EPHY_NAVIGATION_HISTORY_DIRECTION_BACK) {
     if (ephy_gui_is_middle_click () ||
         ephy_link_action_get_button (EPHY_LINK_ACTION (history_action)) == 2) {
+      /* FIXME: in WebKit2 the back/forward list is immutable, so we are not able to
+       * copy it. Ideally the webkit1 code path should also work for webkit2. */
+#ifdef HAVE_WEBKIT2
+      const char *back_uri;
+      WebKitBackForwardList *history;
+      WebKitBackForwardListItem *back_item;
+
+      history = webkit_web_view_get_back_forward_list (web_view);
+      back_item = webkit_back_forward_list_get_back_item (history);
+      back_uri = webkit_back_forward_list_item_get_original_uri (back_item);
+
+      embed = ephy_shell_new_tab (ephy_shell_get_default (),
+                                  EPHY_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (embed))),
+                                  NULL,
+                                  NULL,
+                                  EPHY_NEW_TAB_IN_EXISTING_WINDOW | EPHY_NEW_TAB_DONT_COPY_HISTORY);
+
+      web_view = EPHY_GET_WEBKIT_WEB_VIEW_FROM_EMBED (embed);
+      webkit_web_view_load_uri (web_view, back_uri);
+      gtk_widget_grab_focus (GTK_WIDGET (embed));
+      return;
+    }
+#else
       embed = ephy_shell_new_tab (ephy_shell_get_default (),
                                   EPHY_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (embed))),
                                   embed,
@@ -113,6 +136,8 @@ action_activate (GtkAction *action)
                                   EPHY_NEW_TAB_IN_EXISTING_WINDOW);
       web_view = EPHY_GET_WEBKIT_WEB_VIEW_FROM_EMBED (embed);
     }
+#endif
+
     webkit_web_view_go_back (web_view);
     gtk_widget_grab_focus (GTK_WIDGET (embed));
   } else if (history_action->priv->direction == EPHY_NAVIGATION_HISTORY_DIRECTION_FORWARD) {
@@ -389,21 +414,21 @@ middle_click_handle_on_history_menu_item (EphyNavigationHistoryAction *action,
 #endif
 {
   EphyEmbed *new_embed = NULL;
-  WebKitWebView *web_view;
 #ifndef HAVE_WEBKIT2
+  WebKitWebView *web_view;
   WebKitWebBackForwardList *history;
-#endif
   GList *list;
-  const gchar *url;
   guint current;
+#endif
+  const gchar *url;
   gint offset;
 
-  web_view = EPHY_GET_WEBKIT_WEB_VIEW_FROM_EMBED (embed);
-
 #ifdef HAVE_WEBKIT2
   /* TODO: WebKitBackForwardList is read-only in WebKit2 */
   offset = 0;
 #else
+  web_view = EPHY_GET_WEBKIT_WEB_VIEW_FROM_EMBED (embed);
+
   /* Save old history and item's offset from current */
   history = webkit_web_view_get_back_forward_list (web_view);
   if (action->priv->direction == EPHY_NAVIGATION_HISTORY_DIRECTION_BACK) {
@@ -626,10 +651,11 @@ tool_button_press_event_cb (GtkButton *button,
                                                      (GSourceFunc) menu_timeout_cb,
                                                      data,
                                                      (GDestroyNotify) g_free);
-  } else if (event->button == 3)
+    return FALSE;
+  } else if (event->button == 3) {
     popup_history_menu (action, GTK_WIDGET (button), event);
-
-  return FALSE;
+    return TRUE;
+  }
 }
 
 static gboolean
